@@ -2,9 +2,10 @@
 #'
 #' @export
 #' @param x Variety of things, character, list, or ckan_tag class object
-#' @param ... Further args passed on to \code{\link{tag_show}} if character given
+#' @param ... Further args passed on to [tag_show()] if character given
 #' @examples \dontrun{
-#' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
+#' ckanr_setup(url = "https://demo.ckan.org/",
+#' key = getOption("ckan_demo_key"))
 #'
 #' (tags <- tag_search(query = 'ta'))
 #' tags[[3]]
@@ -41,7 +42,8 @@ print.ckan_tag <- function(x, ...) {
   cat("  Packages (up to 5): ", sift_res(x$packages), "\n", sep = "")
 }
 
-get_tag <- function(id, url = get_default_url(), key = get_default_key(), ...) {
-  res <- ckan_GET(url, 'tag_show', list(id = id), key = key, ...)
+get_tag <- function(id, url = get_default_url(), key = get_default_key(),
+    ...) {
+  res <- ckan_GET(url, 'tag_show', list(id = id), key = key, opts = list(...))
   as_ck(jsl(res), "ckan_tag")
 }
