@@ -15,6 +15,6 @@ package_list_current <- function(offset = 0, limit = 31, url = get_default_url()
 
   args <- cc(list(offset = offset, limit = limit))
   res <- ckan_GET(url, 'current_package_list_with_resources', args, key = key,
-    ...)
+    opts = list(...))
   switch(as, json = res, list = jsl(res), table = jsd(res))
 }
