@@ -28,7 +28,19 @@
 package_revision_list <- function(id, url = get_default_url(),
   key = get_default_key(), as = "list", ...) {
 
-  res <- ckan_GET(url, 'package_revision_list', list(id = id),
+  ver <- try(ckan_version(url)$version_num, silent = TRUE)
+  if (inherits(ver, "try-error")) {
+    ver <- NA
+  }
+
+  if (ver >= 29.0) {
+    warning('The ckan.logic.action.get.package_revision_list endpoint was removed in CKAN 2.9. Returning NULL.')
+    result <- NULL
+  } else {
+    res <- ckan_GET(url, 'package_revision_list', list(id = id),
     key = key, opts = list(...))
-  switch(as, json = res, list = jsl(res), table = jsd(res))
+    result <- switch(as, json = res, list = jsl(res), table = jsd(res))
+  }
+  
+  result
 }
