@@ -6,8 +6,8 @@
 #' @template args
 #' @template key
 #' @details By default the help and success slots are dropped, and only the
-#'   result slot is returned. You can request raw json with \code{as = 'json'}
-#'   then parse yourself to get the help slot.
+#' result slot is returned. You can request raw json with `as = 'json'`
+#' then parse yourself to get the help slot.
 #' @examples \dontrun{
 #' # Setup
 #' ckanr_setup(url = "https://demo.ckan.org/", key = getOption("ckan_demo_key"))
@@ -29,7 +29,8 @@ related_show <- function(id, url = get_default_url(), key = get_default_key(),
   as = 'list', ...) {
 
   id <- as.ckan_related(id, url = url)
-  res <- ckan_GET(url, 'related_show', list(id = id$id), key = key, ...)
+  res <- ckan_GET(url, 'related_show', list(id = id$id), key = key,
+    opts = list(...))
   switch(as, json = res, list = as_ck(jsl(res), "ckan_related"),
     table = jsd(res))
 }
