@@ -1,14 +1,17 @@
 context("package_list_current")
+
+skip_on_cran()
+
 u <- get_test_url()
 
 test_that("package_list_current gives back expected class types and parameter offset works", {
   check_ckan(u)
   a <- package_list_current(limit=30, url=u)
   expect_is(a, "list")
-  expect_less_than(length(a), 30 + 1)
+  expect_lt(length(a), 30 + 1)
   a2 <- package_list_current(offset=5, limit=25, url=u)
   expect_is(a2, "list")
-  expect_less_than(length(a2), 25 + 1)
+  expect_lt(length(a2), 25 + 1)
   expect_equal(tail(a, -5), a2)
 })
 
@@ -19,5 +22,5 @@ test_that("package_list_current works giving back json output", {
   expect_is(b, "character")
   expect_is(b_df, "list")
   expect_is(b_df$result, "data.frame")
-  expect_less_than(nrow(b_df$result), 30 + 1)
+  expect_lt(nrow(b_df$result), 30 + 1)
 })
