@@ -9,15 +9,15 @@ test_that("tag_search gives back expected class types", {
   a <- tag_search(query = "a", url = u)
   expect_is(a, "list")
   expect_is(a[[1]], "ckan_tag")
-  expect_named(a[[1]], c('vocabulary_id', 'id', 'name'))
+  expect_named(a[[1]], c('vocabulary_id', 'id', 'name'), ignore.order = TRUE)
 })
 
 test_that("tag_search works with many queries", {
   check_ckan(u)
-  a <- tag_search(query = c('a', 'al'), url = u)
+  a <- tag_search(query = c('c', 'ck'), url = u)
   expect_is(a, "list")
   expect_is(a[[1]], "ckan_tag")
-  expect_named(a[[1]], c('vocabulary_id', 'id', 'name'))
+  expect_named(a[[1]], c('vocabulary_id', 'id', 'name'), ignore.order = TRUE)
 })
 
 test_that("tag_search works giving back json output", {
